import { isFunction } from "@/utils/types.js"
import Toast from "@/lib/toast/index.js"
import store from "@/store/index.js"
/**
 * @desc 倒计时
 * @param { Number } num 倒计时时间
 * @param { Functiom } cb 回调 
 */
export function timerFn(num = 60, cb) {
	let timer = setInterval(() => {
		cb && isFunction(cb) && cb.call(this, num)
		num --
		if(num < 0) {
			clearInterval(timer)
			timer = null
			return
		}
	}, 1000)
}

/**
 * @desc 节流函数 cv的
 * @param {Function} callback 回调函数
 * @param {Number} wait 间隔时间
 * @return {Function} 节流函数
 */
export function throttle(callback, wait = 3000) {
    let timer = null;
    let startTime;
    return function () {
        const ctx = this;
        const args = arguments;
        const now = +new Date();
        if (startTime && now < startTime + wait) {
			console.log('000==')
            clearTimeout(timer);
            timer = setTimeout(function () {
                startTime = now;
                callback.apply(ctx, args);
            }, wait);
        } else {
			console.logout("33")
            startTime = now;
            callback.apply(ctx, args);
        }
    }
}

/**
 * 联系老板 
 */
export function makePhoneCall() {
	const storeInfo = store.state.user.storeInfo
	if(storeInfo && storeInfo.shop_tel) {
		const phoneNumber = storeInfo.shop_tel
		uni.showModal({
			content: `是否拨打${phoneNumber}`,
			success: res => {
				if(res.confirm) {
					uni.makePhoneCall({
						phoneNumber
					})
				} 
			}
		})
	}
}

/**
 * @微信支付
 * @param { Functiom } cb 回调函数 
 */
export function wxPay(cb) {
	uni.requestPayment({
		timeStamp: '',
		nonceStr: '',
		package: '',
		signType: 'MD5',
		paySign: '',
		success (res) { },
		fail (res) { }
	})
}